@@ -5,16 +5,18 @@ $lang['add_icon'] = 'Neues Icon inzuf&uuml;gen';
 $lang['add_map'] = 'Neue Karte hinzuf&uuml;gen';
 $lang['add_map_point'] = 'Neuen Kartenpunkt hinzuf&uuml;gen';
 $lang['add_point_for_map'] = 'Der Karte &quot;%s&quot; einen neuen Kartenpunkt hinzuf&uuml;gen';
-$lang['aerial'] = 'Aerial';
+$lang['aerial'] = 'Luft';
 $lang['anchor_x'] = 'Anker X Pixel Ort';
 $lang['anchor_y'] = 'Anker Y Pixel Ort';
 $lang['apply'] = 'Best&auml;tigen';
 $lang['ask_delete_icon'] = 'Wollen Sie wirklich dieses Icon aus der Liste entfernen (es werden keine Dateien gel&ouml;scht)?';
 $lang['ask_reset_icons'] = 'Wollen Sie wirklich alle Icons entfernen und auf die programmseitigen Voreinstellungen zur&uuml;cksetzen?';
+$lang['baloon_maptemplate'] = 'Ballon Template';
 $lang['cancel'] = 'Abbrechen';
 $lang['category_template'] = 'Kategorie-Template';
 $lang['center_lat'] = 'Mitte Breitengrad';
 $lang['center_lon'] = 'Mitte L&auml;ngengrad';
+$lang['clearcache'] = 'Geolocate Cache leeren';
 $lang['click'] = 'Klicken';
 $lang['combine_points'] = 'Kombinieren einzelner Marker innerhalb der Reichweite';
 $lang['combined_points_icon'] = 'Icon f&uuml;r kombinierte Nutzung';
@@ -52,7 +54,7 @@ $lang['error_notfound'] = 'Das gew&uuml;nschte Element konnte nicht gefunden wer
 $lang['error_permissiondenied'] = 'Sie ben&ouml;tigen Sie die Berechtigung &#039;%s&#039;, um diese Funktion nutzen zu k&ouml;nnen.';
 $lang['friendlyname'] = 'Calguys Google-Maps';
 $lang['from'] = 'Von';
-$lang['get_directions'] = 'Get Directions';
+$lang['get_directions'] = 'Route';
 $lang['google_api_key'] = 'Google-API-Key';
 $lang['help'] = '<h3>Was macht dieses Modul</h3>
 <p>Dies ist ein Ersatz (in Arbeit) f&uuml;r tsw&#039;s Googlemaps-Modul. Benutzer k&ouml;nnen damit einfach Google Maps erstellen. Die Berechtigungen k&ouml;nnen sehr detailliert eingestellt werden, so dass nur authorisierte Benutzer bestimmte Rechte haben. Au&szlig;erdem ist dynamisches Geo-Locating (mit Zwischenspeicherung) m&ouml;glich. Hiermit k&ouml;nnen direkte Adressen anstelle von GPS-Koordinaten  (L&auml;ngen- und Breitengrade) verwendet werden.</p>
@@ -96,13 +98,15 @@ $lang['help_icon_url'] = 'Specify the URL to the pre-uploaded PNG image.  This i
 $lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page.';
 $lang['help_param_map'] = 'Specify the ID or map name to use for laying out the google map.  If this parameter is not specified, the default map (if any) is used.';
 $lang['help_param_maptemplate'] = 'Specify the name of an existing, non default map template to use for this output.  If this parameter is not specified, the current default map template will be used';
+$lang['help_param_zoomlevel'] = '(integer) Allows overriding the zoom level stored with the map.  Valid values are from 1 to 17';
+$lang['help_param_zoomencompass'] = '(boolean) Allows overriding the zoom encompass setting that is stored with the map.';
 $lang['hide_directions'] = 'Richtungen verbergen';
-$lang['horizontal_bar'] = 'Horizontal Bar';
+$lang['horizontal_bar'] = 'Horizontale Leiste';
 $lang['hybrid'] = 'Hybrid-Modus';
 $lang['id'] = 'ID';
 $lang['icon'] = 'Icon ';
 $lang['imperial'] = 'Imperial';
-$lang['info'] = 'Info';
+$lang['info'] = 'Information';
 $lang['info_address_latlong'] = 'Hinweis: <strong>Entweder</strong> eine Adresse <strong>oder</strong> die geografische Breite und L&auml;nge eingeben. Wenn die Adresse und die geografische Breite und L&auml;nge eingegeben werden, hat die geografische Breite und L&auml;nge Vorrang.';
 $lang['info_anchor_x'] = 'Info Fenster Anker X Pixel Ort';
 $lang['info_anchor_y'] = 'Info Fenster Anker Y Pixel Ort';
@@ -121,29 +125,31 @@ $lang['info_height'] = 'Specify a map height (in pixels)';
 $lang['info_icon_selection'] = 'By default, which icon should be preferred for markers when the category panel is displayed';
 $lang['info_info_trigger'] = 'Specify what should trigger the opening of the info window';
 $lang['info_info_window'] = 'Should an information window be displayed for each map point?';
-$lang['info_infowindow_height'] = 'Specify a height (in pixels) for the info window';
-$lang['info_infowindow_width'] = 'Specify a width (in pixels) for the info window';
-$lang['info_map_type'] = 'Specify the default map type (if type controls are enabled, the user can change the type after the map is displayed)';
+$lang['info_infowindow_height'] = 'Geben Sie eine H&ouml;he (in Pixeln) f&uuml;r das Info Fenster an';
+$lang['info_infowindow_width'] = 'Geben Sie eine Breite (in Pixeln) f&uuml;r das Info Fenster an';
+$lang['info_map_type'] = 'Geben Sie den Standard Kartentyp an (Wenn das Bedienelement f&uuml;r den Kartentyp aktiviert ist, kann der Benutzer den Typ &auml;ndern,  nachdem die Karte geladen ist)';
 $lang['info_nav_control_opt'] = 'Specify the type of navigation controls for the map';
 $lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
 $lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area';
 $lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map';
 $lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable of providing latitude and longitude information.  Do you want to enable this?';
 $lang['info_sidebar'] = 'Should a sidebar containing all map points be displayed?';
-$lang['info_sv_controls'] = 'Should StreetView Controls be displayed on the map?';
-$lang['info_sysdflt_category_template'] = 'System Default &quot;Category List&quot; Template';
-$lang['info_sysdflt_dirform_template'] = 'System Default &quot;Directions Form&quot; Template';
-$lang['info_sysdflt_js_template'] = 'System Default Javascript Template';
-$lang['info_sysdflt_map_template'] = 'System Default map template';
-$lang['info_sysdflt_sidebar_template'] = 'System Default Sidebar Template';
+$lang['info_sv_controls'] = 'Soll das Bedienelement f&uuml;r StreetView auf der Karte angezegit werden?';
+$lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
+$lang['info_sysdflt_baloon_template'] = 'Standard &quot;Ballon&quot; Template';
+$lang['info_sysdflt_category_template'] = 'Standard &quot;Kategorie&quot; Listen-Template';
+$lang['info_sysdflt_dirform_template'] = 'Standard &quot;Richtungs-Formular&quot; Template';
+$lang['info_sysdflt_js_template'] = 'Standard Javascript Template';
+$lang['info_sysdflt_map_template'] = 'Standard Karten template';
+$lang['info_sysdflt_sidebar_template'] = 'Standard Seitenleisten Template';
 $lang['info_sysdflt_template'] = 'This form provides the ability to specify the content that will be displayed when you create a new template of this type.  Editing the content in this form will have no immediate effect on your website';
-$lang['info_type_control_opt'] = 'Specify how the map type controls should be displayed';
-$lang['info_width'] = 'Specify a map width (in pixels)';
-$lang['infowindow_width'] = 'Width of InfoWidnow';
-$lang['infowindow_height'] = 'Height of InfoWindow';
-$lang['info_type_controls'] = 'Allow the user to change the map type?';
-$lang['info_zoom'] = 'Specify an initial zoom level (note, that this parameter is ineffective if &quot;zoom encompass&quot; is used';
-$lang['info_zoom_encompass'] = 'Should the zoom level of the map encompass all of the points?';
+$lang['info_type_control_opt'] = 'Geben Sie an, wie das Bedienelement f&uuml;r den Kartentyp angezeigt werden soll';
+$lang['info_width'] = 'Geben Sie eine Kartenbreite an (in Pixeln)';
+$lang['infowindow_width'] = 'Breite des Info Fensters';
+$lang['infowindow_height'] = 'H&ouml;he des Info Fensters';
+$lang['info_type_controls'] = 'Benutzer erlauben, den Kartentyp zu &auml;ndern?';
+$lang['info_zoom'] = 'Geben Sie eine erste Zoomstufe (beachten Sie, dass dieser Parameter wirkungslos ist, wenn &quot;Zoom umfassen&quot;  verwendet wird)';
+$lang['info_zoom_encompass'] = 'Soll die Zoomstufe der Karte alle Punkte umfassen?';
 $lang['js_template'] = 'Javascript Template';
 $lang['large'] = 'Gro&szlig;';
 $lang['latitude'] = 'Breitengrad';
@@ -151,37 +157,39 @@ $lang['latlong'] = 'Breitengrad / L&auml;ngengrad';
 $lang['location'] = 'Ort';
 $lang['longitude'] = 'L&auml;ngengrad';
 $lang['make_default'] = 'Dieses Icon als Standard-Icon festlegen';
-$lang['marker_categories'] = 'Marker Categories';
-$lang['marker_icons'] = 'Marker Icons';
+$lang['marker_categories'] = 'Marker Kategorien';
+$lang['marker_icons'] = 'Marker Symbole';
+$lang['marker_skipped'] = 'Geolocation (adresse lat/long) fehlgeschlagen.. Marker &quot;%s&quot; &uuml;bersprungen';
 $lang['map'] = 'Karte';
 $lang['maps'] = 'Karten';
 $lang['maptemplate_addedit'] = 'Ein Karten-Template hinzuf&uuml;gen/bearbeiten';
 $lang['map_name'] = 'Kartenname';
-$lang['map_template'] = 'Map Template';
+$lang['map_template'] = 'Mappen Template';
 $lang['map_templates'] = 'Karten-Templates';
-$lang['map_type'] = 'Map Type';
-$lang['metric'] = 'Metric';
+$lang['map_type'] = 'Kartentyp';
+$lang['metric'] = 'Metrisch';
 $lang['moddescription'] = 'Ein einfaches Modul zum Erstellen von Google Maps';
 $lang['mouseover'] = 'MouseOver ';
-$lang['msg_categoryadded'] = 'Category Added';
-$lang['msg_categorydeleted'] = 'Category Deleted';
-$lang['msg_categoryupdated'] = 'Category Updated';
+$lang['msg_addresscache_cleared'] = 'Geolocation Cache geleert';
+$lang['msg_categoryadded'] = 'Kategorie hinzugef&uuml;gt';
+$lang['msg_categorydeleted'] = 'Kategorie gel&ouml;scht';
+$lang['msg_categoryupdated'] = 'Kategorie aktualisiert';
 $lang['msg_default_icon_uchanged'] = 'Das Standard-Icon wurde ge&auml;ndert';
 $lang['msg_icons_reset'] = 'Die Icons wurden auf die programmseitigen Voreinstellungen zur&uuml;ckgesetzt';
 $lang['msg_icon_removed'] = 'Das Icon wurde aus der Datenbank entfernt. Es wurden keine Dateien gel&ouml;scht';
 $lang['msg_icon_updated'] = 'Die Icon-Information wurde ge&auml;ndert';
 $lang['name'] = 'Name ';
-$lang['nav_control_opt'] = 'Navigation Control Size';
-$lang['none'] = 'None';
-$lang['panel'] = 'Panel';
+$lang['nav_control_opt'] = 'Gr&ouml;&szlig;e der Kontroll-Navigation ';
+$lang['none'] = 'Keine(r)';
+$lang['panel'] = 'Feld';
 $lang['points'] = 'Punkt';
-$lang['point_combine_fudge'] = 'Specify a radius that specifies which points should be combined.';
-$lang['point_combine_icon'] = 'Combined Points Icon';
+$lang['point_combine_fudge'] = 'Geben Sie einen Radius an, welcher bestimmt welche Punkte zusammengefasst werden sollen.';
+$lang['point_combine_icon'] = 'Symbol f&uuml;r Kombinierte punkte';
 $lang['point_name'] = 'Punktname';
 $lang['point_type'] = 'Punkttyp';
-$lang['policy_cachefirst'] = 'Read cache first then lookup address online';
-$lang['policy_cacheonly'] = 'Always use the cache';
-$lang['policy_nocache'] = 'Never use the cache (online lookup only)';
+$lang['policy_cachefirst'] = 'Lese-Zwischenspeicher zuerst, dann Online-Abfrage f&uuml;rAdresse';
+$lang['policy_cacheonly'] = 'Verwenden Sie immer den Zwischenspeicher';
+$lang['policy_nocache'] = 'Verwenden niemals den Zwischenspeicher (Online-Abfrage nur)';
 $lang['postinstall'] = 'Das Modul CGGoogleMaps wurde installiert.';
 $lang['postuninstall'] = 'Das Modul CGGoogleMaps und alle relevanten Daten wurden entfernt';
 $lang['preferences'] = 'Voreinstellungen';
@@ -193,10 +201,10 @@ $lang['prompt_icon_selection'] = 'Icon Auswahl';
 $lang['prompt_info_window'] = 'Info-Fenster anzeigen';
 $lang['prompt_info_trigger'] = 'Info-Fenster Ausl&ouml;ser anzeigen';
 $lang['prompt_lookup_policy'] = 'Lookup Regel';
-$lang['prompt_lookup_service'] = 'Lookup Service';
-$lang['prompt_to_here'] = 'To Here';
-$lang['prompt_sensor'] = 'Supply Geographic location information to the map';
-$lang['prompt_zoom'] = 'Zoom Level';
+$lang['prompt_lookup_service'] = 'Suchdienst';
+$lang['prompt_to_here'] = 'Hierher';
+$lang['prompt_sensor'] = 'Liefere Informationen der Geographische Lage , an die Karte';
+$lang['prompt_zoom'] = 'Zoomstufe';
 $lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul entfernen?';
 $lang['reset'] = 'Zur&uuml;cksetzen';
 $lang['reset_icons'] = 'Icons zur&uuml;cksetzen';
@@ -205,10 +213,11 @@ $lang['scalecontrols'] = 'Ma&szlig;stab anzeigen';
 $lang['set_dflt_map'] = 'Die Karte als Standard festlegen';
 $lang['show_category_panel'] = 'Kategorie-Feld anzeigen';
 $lang['sidebar'] = 'Sidebar anzeigen';
-$lang['sidebar_template'] = 'Sidebar Template';
+$lang['sidebar_template'] = 'Seitenleisten Template';
 $lang['small'] = 'Klein';
 $lang['submit'] = 'Absenden';
 $lang['sv_controls'] = 'Streetview Steuerung anzeigen';
+$lang['sv_radius'] = 'Streetview Suchradius';
 $lang['tab_advanced'] = 'Erweitert';
 $lang['tab_directions'] = 'Richtungen';
 $lang['tab_jstemplate'] = 'Javascript Template';
@@ -226,8 +235,8 @@ $lang['width'] = 'Breite';
 $lang['window'] = 'Fenster';
 $lang['zoom_encompass'] = 'Zoom Encompass';
 $lang['qca'] = 'P0-1458450664-1284573084918';
-$lang['utmz'] = '156861353.1290606954.507.40.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.1164361908.1285153768.1290628878.1290638483.513';
+$lang['utma'] = '156861353.423163579.1322242094.1322242094.1322242094.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1322242094.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
