@@ -4,17 +4,19 @@ $lang['add_category'] = 'Voeg Categorie toe';
 $lang['add_icon'] = 'Voeg Pictogram toe';
 $lang['add_map'] = 'Voeg kaart toe';
 $lang['add_map_point'] = 'Voeg een punt op de kaart toe';
-$lang['add_point_for_map'] = 'Voeg punt toe aan kaart &quot;%s&quot;';
+$lang['add_point_for_map'] = 'Voeg punt toe aan kaart &amp;quot;%s&amp;quot;';
 $lang['aerial'] = 'Antenne';
 $lang['anchor_x'] = 'Anchor X pixel locatie';
 $lang['anchor_y'] = 'Anchor Y pixel locatie';
 $lang['apply'] = 'Toepassen';
 $lang['ask_delete_icon'] = 'Weet u zeker dat u dit pictogram wilt verwijderen van de lijst? (er worden g&eacute;&eacute;n bestanden gewist)';
 $lang['ask_reset_icons'] = 'Weet u zeker dat u alle pictogrammen wilt verwijderen en wil terug gaan naar de standaaard instellingen?';
+$lang['baloon_maptemplate'] = 'Ballon sjabloon';
 $lang['cancel'] = 'Annuleren';
 $lang['category_template'] = 'Categorieweergave sjabloon';
 $lang['center_lat'] = 'Centreer Breedtegraad';
 $lang['center_lon'] = 'Centreer Lengtegraad';
+$lang['clearcache'] = 'Leeg de Geolocatie Cache';
 $lang['click'] = 'Klik';
 $lang['combine_points'] = 'Combineer individuele markers die binnen dit bereik zijn';
 $lang['combined_points_icon'] = 'Icon om te gebruiken bij gecombineerde punten';
@@ -29,12 +31,12 @@ $lang['delete_map'] = 'Verwijder Kaart';
 $lang['delete_map_point'] = 'Verwijder punt van kaart';
 $lang['description'] = 'Omschrijving';
 $lang['directions'] = 'Laat bestemming zien';
-$lang['directions_dest'] = 'Waar bestemmingen moeten worden getekend';
-$lang['directions_units'] = 'Directions Units';
-$lang['dirform_maptemplate'] = 'Directions Form Template';
+$lang['directions_dest'] = 'Waar moeten bestemmingen worden getekend';
+$lang['directions_units'] = 'Routebeschrijvingen';
+$lang['dirform_maptemplate'] = 'Routebeschrijvingssjabloon';
 $lang['dropdown'] = 'Dropdown ';
 $lang['edit'] = 'Wijzig';
-$lang['edit_category'] = 'Edit Marker Category';
+$lang['edit_category'] = 'Bewerk Marker categorie';
 $lang['edit_icon'] = 'Verander deze pictogram';
 $lang['edit_map'] = 'Bewerk kaart';
 $lang['edit_map_point'] = 'Bewerk kaart punt';
@@ -54,16 +56,22 @@ $lang['friendlyname'] = 'Calguys Google Maps ';
 $lang['from'] = 'Formulier';
 $lang['get_directions'] = 'Verkrijg bestemmingen';
 $lang['google_api_key'] = 'Google API sleutel';
-$lang['help'] = '<h3>What does this do </h3>
-<p>This is a replacement (in progress) for tsw&#039;s googlemaps module that allows users to easily create google maps, whilst allowing atomic permissions so that only authorized users have certain abilities.  It also allows for dynamic geolocating (with caching) so that you can specify a location by address instead of by latitude and longitude.</p>
-<p>This module allows multiple maps to be displayed on a single page, and multiple &#039;markers&#039; or points on each map, so that it can be used in a way similar to frapper.</p>
+$lang['help'] = '<h3>What does this do</h3>
+  <p>This module provides a quick, convenient, yet flexible and extendable way to place google maps on a page providing a number of built in functions, and providing easy extendability for those familiar with Javascript and the Google Maps API&#039;;
 <h3>Features:</h3>
 <ul>
   <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
   <li>Flexible marker icon management.</li>
-  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
+  <li>The ability to categorize markers.  Markers can belong to more than one category.</li>
+  <li>Infowindow content can be specified using HTML</li>
+  <li>Streetview support</li>
+  <li>The ability to display a sidebar of all markers associated with a map.</li>
+  <li>The ability to display a category panel, and hide icons by unchecking a category checkbox.</li>
+  <li>Directions support (either by displaying the route in the map (and with directions in a seperate panel), or by opening a new window</li>
+  <li>Reads sensor information from GPS sensors on mobile devices.</li>
   <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
-  <li>Dynamic icon control for each marker point.</li>
+  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
+  <li>Uses jquery for advanced DOM manipulation.</li>
 </ul>
 <h3>How Do I Use It?</h3>
 <ul>
@@ -74,7 +82,7 @@ $lang['help'] = '<h3>What does this do </h3>
     <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
   </ul>
 </li>
-<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking</p>
+<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking.  Note that when resetting one of the map templates to defaults, you must still press the &amp;quot;Apply&amp;quot; or &amp;quot;Apply&amp;quot; buttons.</p>
 <li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
 <li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
 <li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
@@ -84,29 +92,65 @@ $lang['help'] = '<h3>What does this do </h3>
 <p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
 <h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
 <p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
-<h5>Parameters:<h5>
+<h4>Usage:</h4>
+<pre><code>{cggm_add_dynpoint map=1 name=&#039;New York&#039; address=&#039;New York, NY&#039; icon=&#039;food&#039;}</code></pre><br/>
+<h4>Parameters:</h4>
   <ul> 
-<li><strong>required</strong> - map : The ID of the map to add the point to</li>
+<li><strong>required</strong> - map : The (integer) ID of the map to add the point to</li>
 <li><strong>required</strong> - name : The name of the point to add</li>
-<li><em>optional</em> - description : The HTML content to show in the popup bubble</li>
-<li><em>optional</em> - address : The address of the location you are adding.</li>
+<li><em>optional</em> - desc/description : The HTML content to show in the info window</li>
+<li><em>optional</em> - address : The address of the location you are adding. (you must specify an address, or lat and long parameters)</li>
 <li><em>optional</em> - lat : The latitude of the location you are adding.</li>
 <li><em>optional</em> - long : The longitude of the location you are adding.</li>
+<li><em>optional</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
+<li><em>optional</em> - tooltip : A tooltip to display when hovering over a point.</li>
 <li><em>optional</em> - icon : The name of an icon to use for this point.</li>
-<li><em>optional</em> - tooltip : Title text to display when hovering a point</li>
-<li><em>optional</em> - sidebar_class : Optional class to associate with the sidebar list item for this point.</li>
-<li><em>optional</em> - sidebar_html : Optional text to include for this marker on the sidebar.</li>
   </ul>
 <br/>
 <p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
 <p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
-</ul>';
+</ul>
+<h3>Upgrade Information:</h3>
+<p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
+<p>Also: The sidebar_html, and sidebar_class parameters have been removed from the {cggm_add_dynpoint} smarty plugin.  This is due to the category functionality that has been added.</p>
+<h3>Support</h3>
+<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
+<ul>
+<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
+module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
+<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
+<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
+<li>Lastly, you may have some success emailing the author directly.</li>  
+</ul>
+<h3>Requirements</h3>
+<p>This map functionality makes extensive use of <strong>JQuery</strong> it is your responsibility to include jquery in pages that use these maps and ensure that it is loaded before the map is called.  The easiest way to do this is by installing the JQueryTools module and adding {JQueryTools action=incjs} into the head portion of your page template.</p>
+<h3>Copyright and License</h3>
+<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
+<p>This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.</p>
+<p>However, as a special exception to the GPL, this software is distributed
+as an addon module to CMS Made Simple.  You may not use this software
+in any Non GPL version of CMS Made simple, or in any version of CMS
+Made simple that does not indicate clearly and obviously in its admin 
+section that the site was built with CMS Made simple.</p>
+<p>This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['height'] = 'Hoogte';
 $lang['help_anchor_location'] = '<strong>Opmerking:</strong> Anchor locaties specificeren de pixel locatie (in relatie tot de linkerboven hoek van de afbeelding) waar de pictogram moet komen als markeerpunt. Als er geen waarde is gegeven, wordt het midden van de pictogram gebruikt';
 $lang['help_icon_url'] = 'Benoem de URL van de ge&uuml;ploade PNG afbeelding.  Deze afbeelding mag niet groter zijn dan 32x32px, en moet transparant zijn. De URL moet vanuit de root van uw website worden benoemd';
 $lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page. ';
 $lang['help_param_map'] = 'Specificeer een ID of kaartnaam voor het weergeven van de Google Map. Als deze parameter niet wordt opgegeven, dan wordt de standaard map gebruikt.';
 $lang['help_param_maptemplate'] = 'Geef de naam op van een bestaande, niet standaard (default) map sjabloon om te gebruiken voor deze output. Als deze parameter niet gespecificeerd is, zal de huidige als standaard gekenmerkte sjabloon toegepast worden.';
+$lang['help_param_zoomlevel'] = '(integer) Staat toe het zoomniveau van de kaart te overschrijven. Geldige waarden zijn 1 tot en met 17';
+$lang['help_param_zoomencompass'] = '(boolean) Staat toe de zoomomgevinginstelling aan te passen.';
 $lang['hide_directions'] = 'Verberg bestemmingen';
 $lang['horizontal_bar'] = 'Horizontale balk';
 $lang['hybrid'] = 'Kruising';
@@ -124,24 +168,26 @@ $lang['info_center_lon'] = 'The Center longitude is optional.  If specified it w
 $lang['info_combine_points'] = 'If selected, points that are within a specified radius of each other will be combined into one marker on the map.  This functionality is useful if multiple entries exist at the same (or almost the same) coordinates, to ease in selection.  This functionality is independant of the map zoom level.  ';
 $lang['info_controls'] = 'Moeten zoom en pan buttons worden weergegeven?';
 $lang['info_controls_size'] = 'Geef de grootte op van de buttons op de kaart';
-$lang['info_default_icon'] = 'The default icon is used when no other icon is specified for a map point';
-$lang['info_directions'] = 'Allow the user to request directions from, or to a map point';
-$lang['info_directions_dest'] = 'Specify how directions should be handled.  Should they be displayed in a new window, or in the map panel';
-$lang['info_directions_units'] = 'Specify how the units should be displayed for directions.  Metric, or imperial.';
+$lang['info_default_icon'] = 'Het standaard pictogram dat wordt gebruikt als er geen pictogram is opgegeven voor een punt op de kaart';
+$lang['info_directions'] = 'Sta toe dat de gebruiker een routebeschrijving op vraagt van of naar een punt op de kaart';
+$lang['info_directions_dest'] = 'Specificeer hoe een routebeschrijving moet worden uitgevoerd. Moet deze worden weergegeven in een nieuw venster of bij het kaartpaneel?';
+$lang['info_directions_units'] = 'Geef aan welke eenheden je wilt gebruiken voor de routebeschrijving, metrisch (kilometers en meters) of imperiaal (Miles, Feet, Yards)';
 $lang['info_height'] = 'Geef de hoogte van de map op (in pixels)';
-$lang['info_icon_selection'] = 'By default, which icon should be preferred for markers when the category panel is displayed';
-$lang['info_info_trigger'] = 'Specify what should trigger the opening of the info window';
-$lang['info_info_window'] = 'Should an information window be displayed for each map point?';
+$lang['info_icon_selection'] = 'Welk pictogram moet standaard worden weergeven voor aanduidingen op de kaart, wanneer het categoriepaneel wordt weergegeven?';
+$lang['info_info_trigger'] = 'Geef op wanneer het informatievenster moet worden weergegeven';
+$lang['info_info_window'] = 'Moet er een informatievenster worden weergegeven voor ieder punt op de map?';
 $lang['info_infowindow_height'] = 'Geef de hoogte (in pixels) op voor het informatievenster';
 $lang['info_infowindow_width'] = 'Geef de breedte (in pixels) op voor het informatievenster';
-$lang['info_map_type'] = 'Specify the default map type (if type controls are enabled, the user can change the type after the map is displayed)';
-$lang['info_nav_control_opt'] = 'Specify the type of navigation controls for the map';
+$lang['info_map_type'] = 'Geef het standaard kaarttype op (als de typebesturingselementen worden weergeven kan de gebruiker het type wijzigen nadat de kaart is geladen)';
+$lang['info_nav_control_opt'] = 'Geef het type van de navigatie-elementen op voor de kaart';
 $lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
 $lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area';
 $lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map';
 $lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable of providing latitude and longitude information.  Do you want to enable this?';
 $lang['info_sidebar'] = 'Moet er een sidebar met alle punten op de kaart worden weergegeven?';
 $lang['info_sv_controls'] = 'Moeten StreetView buttons worden weergegeven op de kaart?';
+$lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
+$lang['info_sysdflt_baloon_template'] = 'Systeemstandaard &quot;Ballon&quot; sjaboon';
 $lang['info_sysdflt_category_template'] = 'Systeemstandaard &quot;Categorielijst&quot; sjabloon';
 $lang['info_sysdflt_dirform_template'] = 'Systeemstandaard &quot;Bestemmingsformulier&quot; sjabloon';
 $lang['info_sysdflt_js_template'] = 'Systeemstandaard Javascript sjabloon';
@@ -153,8 +199,8 @@ $lang['info_width'] = 'Geef een mapbreedte op';
 $lang['infowindow_width'] = 'Breedte van informatievenster';
 $lang['infowindow_height'] = 'Hoogte van informatievenster';
 $lang['info_type_controls'] = 'Sta gebruiker toe om het type kaart te wijzigen?';
-$lang['info_zoom'] = 'Specify an initial zoom level (note, that this parameter is ineffective if &quot;zoom encompass&quot; is used';
-$lang['info_zoom_encompass'] = 'Should the zoom level of the map encompass all of the points?';
+$lang['info_zoom'] = 'Geef een initeel zoomlevel op (opmerking, deze parameter werkt niet indien het &#039;zoom encompass&#039; in gebruik is)';
+$lang['info_zoom_encompass'] = 'Moet het zoomlevel zodanig zijn ingesteld dat alle aangegeven punten worden weergegeven?';
 $lang['js_template'] = 'Javascript sjabloon';
 $lang['large'] = 'Groot';
 $lang['latitude'] = 'Breedtegraad';
@@ -164,6 +210,7 @@ $lang['longitude'] = 'Lengtegraad';
 $lang['make_default'] = 'Gebruik standaard dit pictogram';
 $lang['marker_categories'] = 'Marker Categorie&euml;n';
 $lang['marker_icons'] = 'Markeer Pictogram';
+$lang['marker_skipped'] = 'Geolocation (adres te kort/lang) mislukt.. marker &quot;%s&quot; is overgeslagen';
 $lang['map'] = 'Kaart';
 $lang['maps'] = 'Kaarten';
 $lang['maptemplate_addedit'] = 'toevoegen/wijzigen map sjabloon';
@@ -174,6 +221,7 @@ $lang['map_type'] = 'Kaarttype';
 $lang['metric'] = 'Metrisch';
 $lang['moddescription'] = 'Module om Google maps te maken';
 $lang['mouseover'] = 'MuisOver';
+$lang['msg_addresscache_cleared'] = 'Geolocatie cache geleegd';
 $lang['msg_categoryadded'] = 'Categorie toegevoegd';
 $lang['msg_categorydeleted'] = 'Categorie verwijderd';
 $lang['msg_categoryupdated'] = 'Categorie bijgewerkt';
@@ -202,11 +250,11 @@ $lang['prompt_directions'] = 'Bestemmingen';
 $lang['prompt_from_here'] = 'Vanaf hier';
 $lang['prompt_icon_selection'] = 'Pictogramselectie';
 $lang['prompt_info_window'] = 'Laat informatievenster zien';
-$lang['prompt_info_trigger'] = 'Info Window Trigger';
+$lang['prompt_info_trigger'] = 'Informatievenster Trigger';
 $lang['prompt_lookup_policy'] = 'Opzoekbeleid';
 $lang['prompt_lookup_service'] = 'Opzoekservice';
 $lang['prompt_to_here'] = 'Naar hier';
-$lang['prompt_sensor'] = 'Supply Geographic location information to the map';
+$lang['prompt_sensor'] = 'Voeg geografischelocatie informatie toe aan de kaart';
 $lang['prompt_zoom'] = 'Zoomniveau';
 $lang['really_uninstall'] = 'Weet je zeker dat je deze module wilt verwijderen?';
 $lang['reset'] = 'Herstel';
@@ -220,6 +268,7 @@ $lang['sidebar_template'] = 'Sidebar sjabloon';
 $lang['small'] = 'Klein';
 $lang['submit'] = 'Verzend';
 $lang['sv_controls'] = 'Laat StreetView buttons zien';
+$lang['sv_radius'] = 'Streetview Zoek Radius';
 $lang['tab_advanced'] = 'Geavanceerd';
 $lang['tab_directions'] = 'Bestemmingen';
 $lang['tab_jstemplate'] = 'Javascript sjabloon';
@@ -236,9 +285,9 @@ $lang['use_marker_icon'] = 'Kies een markeerpictogram';
 $lang['width'] = 'Breedte';
 $lang['window'] = 'Venster';
 $lang['zoom_encompass'] = 'Inzoom omgeving';
-$lang['utma'] = '156861353.1852221271.1287479092.1294509952.1294593558.77';
-$lang['utmz'] = '156861353.1294509952.76.54.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/34|utmcmd=referral';
-$lang['qca'] = 'P0-161031897-1287479092171';
 $lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.448615243.1322242255.1322242255.1322242255.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1322242255.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['qca'] = 'P0-854772080-1311691512069';
 ?>
\ No newline at end of file
