@@ -60,7 +60,7 @@ class cggm_map_operations
     self::$_sidebar_tpl = $mod->GetTemplate(CGGM_NEWSIDEBAR_TEMPLATE);
     self::$_cat_tpl = $mod->GetTemplate(CGGM_NEWCATEGORY_TEMPLATE);
     self::$_dirform_tpl = $mod->GetTemplate(CGGM_NEWDIRFORM_TEMPLATE);
-    self::$_baloon_tpl = $mod->GetTemplate(CGGM_NEWBALOON_TEMPLATE);
+    self::$_baloonform_tpl = $mod->GetTemplate(CGGM_NEWBALOON_TEMPLATE);
   }
 
   public static function build_new_map($params)
@@ -78,7 +78,7 @@ class cggm_map_operations
     $obj->set_sidebar_template(self::$_sidebar_tpl);
     $obj->set_category_template(self::$_cat_tpl);
     $obj->set_dirform_template(self::$_dirform_tpl);
-    $obj->set_baloon_template(self::$_baloon_tpl);
+    $obj->set_baloon_template(self::$_baloonform_tpl);
     return $obj;
   }
 
